@@ -2,34 +2,37 @@ import re
 from os import path
 from typing import Any
 
+import latest_user_agents
 import requests
 from requests.models import Response
 
-# from .. import web_driver
 from ..config import config
+from ..core.errors.download_failed import DownloadFailed
 
-_user_agent = (
-    "user-agent=Mozilla/5.0 (Windows NT 6.1; Win64; x64) "
-    + "AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.125 Safari/537.36"
-)
-_headers = {"User-Agent": _user_agent}
+_headers = {"User-Agent": latest_user_agents.get_random_user_agent()}
 
 
 class Downloader:
     def get(self, url: str) -> Any:
-        with requests.get(url, headers=_headers) as response:
+        headers = _headers
+
+        with requests.get(url, headers=headers) as response:
             return response.json(strict=False)
 
     def download(self, url: str, filename: str) -> str:
         """Download the specified mod
         Returns:
             Filename of the downloaded and saved file
+        Exception:
+            DownloadFailed if the download failed
         """
 
         if config.pretend:
             return filename
 
         with requests.get(url, headers=_headers) as response:
+            if response.status_code != 200:
+                raise DownloadFailed(response.status_code, response.reason, str(response.content))
 
             if len(filename) == 0:
                 filename = Downloader._get_filename(response)
