@@ -1,4 +1,13 @@
-from .util.helper import Helper, helper  # lgtm[py/unused-import]
+import pytest
+
+from .util.helper import Helper
+
+
+@pytest.fixture
+def helper():
+    helper = Helper()
+    yield helper
+    helper.unstub()
 
 
 def test_reinstall_mod_after_manual_removal(helper: Helper):
@@ -32,3 +41,12 @@ def test_remember_slug_for_installed_mod_if_mod_id_varies(helper: Helper):
 
     assert code == 0
     assert helper.exists_in_db("unearthed")
+
+
+def test_install_from_modrinth(helper: Helper):
+    code = helper.run("install", "lithium=modrinth:lithium")
+    lithium_mod = helper.get_mod_in_dir_like("*lithium*.jar")
+    assert lithium_mod is not None
+    assert code == 0
+
+    lithium_mod.unlink()
